@@ -1,5 +1,6 @@
 """Declares :class:`GoogleCloudStorageBackend`."""
 import os
+import tempfile
 
 import aiohttp
 import gcloud.aio.storage
@@ -96,6 +97,19 @@ class StorageBackend(RemoteStorageBackendMixin, BaseStorageBackend):
         blob = self.bucket.blob(self.storage_path(path))
         blob.upload_from_filename(src)
 
+    def slice(self, path, length, offset=0):
+        """Returns a slice of the blob represented by `path`."""
+        # The Google library uses `end`, which unlike an offset is inclusive
+        # of the upper bound.
+        if length > 1:
+            length -= 1
+        self._validate_slice(length, offset)
+        blob = self.bucket.blob(self.storage_path(path))
+        with tempfile.NamedTemporaryFile('w+b') as f:
+            blob.download_to_file(f, start=offset, end=offset+length)
+            f.seek(0)
+            return f.read()
+
     def unlink(self, path):
         """Remove a path."""
         self.bucket.delete_blobs(
