@@ -11,6 +11,7 @@ from .base import BaseStorageBackend
 
 class LocalDiskBackend(BaseStorageBackend):
     """A storage backend that uses the local filesystem."""
+    capabilities = ['slice', 'slice:async']
     kind = 'local'
 
     async def async_download(self, path, dst, decryptor=None):
@@ -42,6 +43,10 @@ class LocalDiskBackend(BaseStorageBackend):
                 async for chunk in reader:
                     await writer(chunk)
 
+    async def async_slice(self, path, length, offset=0, mode='r'):
+        """Returns a slice of the blob represented by `path`."""
+        return self.slice(path, length, offset, mode)
+
     def close(self, handler):
         """Flush and close the IO object.
 
@@ -89,6 +94,14 @@ class LocalDiskBackend(BaseStorageBackend):
             os.makedirs(os.path.dirname(dst))
         shutil.copy2(src, dst)
 
+    def slice(self, path, length, offset=0, mode='r'):
+        """Returns a slice of the blob represented by `path`."""
+        self._validate_slice(length, offset)
+        with open(self.storage_path(path), mode) as f:
+            if offset:
+                f.seek(offset)
+            return f.read(length)
+
     def unlink(self, path):
         """Remove a path."""
         dst = self.storage_path(path)
